==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/script/terminaly.js <==
/* 
 * Pavel Rudol, RON Software
 *  10.11.2015
 */


/* global debugMode, ron */

var terminaly = { };

/**
 * JSON objekt s aktualnim stavem terminalu
 * @returns {terminaly.stavTerminalu}
 */
terminaly.stavTerminalu = function() {
    /** @type {int} timestamp posledniho nastaveni */
    this.posledniNastaveni = 0;
    /** @type {int} timestamp posledniho nacteni */
    this.posledniNacteni = 0;
    /** @type {string} datum posledniho nastaveni textove */
    this.posledniNastaveniStr = '';
    /** @type {string} datum posledniho nacteni textove */
    this.posledniNacteniStr = '';    
    /** @type {string} pocet nastaveni */
    this.pocetNastaveni = 0;
    /** @type {string} pocet nacteni */
    this.pocetNacteni = 0;
    /** @type {boolean} zda byl agent dokoncen uspesne */
    this.vysledekAgenta = 0;
    /** @type {boolean} zda byl json odeslan uspesne */
    this.result = 0;
    /** @type {error[]} seznam chyb */
    this.errors = [];
};

terminaly.nastavGenerovani = function (dobaKontroly, interval) {
    
    var url = '?menuid=terminaly&record=';
    
    var info = $('#terminal_generovani_info').text();
    var dots = new Number();
    var kontrolaStavuInt;
    var loadingInt;
    
    var maxKontrola = new Number(dobaKontroly * 60 * 1000);//new Number(100000);
    var intervalKontroly = new Number(interval * 1000);//new Number(5000);
    
    if (debugMode) {
        console.log('Kontrolu provadet ' + maxKontrola + ' ms, interval kontroly: ' + intervalKontroly + ' ms');
    }
    
    /**
     * odesle AJAXem POST pozadavek na generovani terminalu, pokud server nestihne odpovedet spusti se v intervalu intervalKontroly 
     * funkce, ktera zjistuje aktualni stav terminalu z dataze a porovnava se stavem, ktery byl pred odeslanim pozadavku
     * Pokud se zmeni stav, ukonci porovnani a zobrazi info o dokonceni a tlacitko pro uzavreni dialogu. 
     * Pokud pred vyprsenim intervalu maxKontrola neni zapsana zmena stavu, vypise chybovou hlasku, kterou vratil agent a umozni zavrit dialog.     
     * 
     * @returns {Boolean}
     */
    var provedGenerovani = function () {    
        //kod aktualniho terminalu
        var terminalKod = $(':hidden[name="terminal_kod"]').val();
        
        var urlTerminalu = url+terminalKod;
        
        //nacteni stavu terminalu pred spustenim generovani
        var posledniNastaveni = new Number();
        var pocetNastaveni = new Number();
        posledniNastaveni = parseInt($('#hlavickaterminalu_casnastaveni_timestamp').val());
        pocetNastaveni = parseInt($('#hlavickaterminalu_pocetnastaveni_int').val());
        
        //aktualni stav terminalu se pouzije ve funkce, ktera kontroluje stav
        var aktualniStav = { 
                            posledniNastaveni: posledniNastaveni,
                            pocetNastaveni: pocetNastaveni,
        };
        
        $.ajax({
                url: url+terminalKod,
                method: 'POST',
                data: {
                    terminal_kod: terminalKod,
                    nastaveni: true,
                    json: true,
                },
                /**
                 * 
                 * @param {terminaly.stavTerminalu} data
                 * @returns {undefined}
                 */
                success: function (data) {
                    //agent odeslal informaci o stavu agenta 
                    //(generovani jeste nemuselo skoncit, ale mohl vyprset limit pro spojeni php skriptu s remote executorem)
                    if (data) {
                        //generovani skoncilo uspesne
                        if (data.vysledekAgenta) {
                            $('#terminal_generovani_info').text(ron.translate('GenerovaniUspesne'));   
                            $('#zmenaStavu').val(1);
                            aktualizujStav(data);
                            umoznitZavreniDialogu();
                        }
                        //generovani skoncilo chybou, nebo nestihl v casovem limitu odpovedet remote executor
                        //spusti se zjistovani stavu z databaze pro overeni, zda opravdu generovani skoncilo chybou
                        else {
                            //pri generovani doslo k chybe a jiz se zmenil i stav, vypise se do stranky a umozni zavreni dialogu
                            if (data.pocetNastaveni > aktualniStav.pocetNastaveni) {
                                aktualizujStav(data);
                                //vypsani chyby do dialogoveho okna
                                if ((data.errors) && (parseInt($('#zmenaStavu').val()) === 0)) {
                                    ron.showError(data,$('#terminal_generovani_info'));
                                    $('#terminal_generovani_info').css('color','red');
                                }
                                umoznitZavreniDialogu();
                            }
                            //stav se jeste nezmenil, zapne se pravidelne zjistovani stavu
                            else {
                                //ve zvolenem intervalu se bude spoustet funkce, ktera kontroluje stav terminalu v DB
                                kontrolaStavuInt = setInterval(zkontrolujStav,intervalKontroly,urlTerminalu,aktualniStav);
                                //nastaveni maximalniho casoveho limitu ve kterem se bude spoustet konrola stavu                            
                                setTimeout(function(){ 
                                    //po max. zvolenem case ukonci periodickou kontrolu stavu
                                    clearInterval(kontrolaStavuInt);
                                    if (debugMode) {
                                        console.log('Je zmena informacni zpravy: ' + $('#zmenaStavu').val());
                                    }
                                    //pri generovani doslo k chybe a pravidelne spousteni funkce zkontroluj stav nezjistilo zmenu,
                                    //vypise se posledni chyba z agenta
                                    if ((data.errors) && (parseInt($('#zmenaStavu').val()) === 0)) {
                                        ron.showError(data,$('#terminal_generovani_info'));
                                        //$('#terminal_generovani_info').text(data.errors[0].errorText);
                                        $('#terminal_generovani_info').css('color','red');
                                        aktualizujStav(data);                                    
                                    }
                                    umoznitZavreniDialogu();
                                }, maxKontrola);
                            }
                        }
                        
                        if (debugMode) {
                            console.log('Vysledek generovani: ');
                            console.log(data);
                        }
                        
                    }
                },
                //pri odesilani pozadavku na generovani terminalu doslo k chybe
                error: function (jqXHR, textStatus) {
                    $('#terminal_generovani_info').text(ron.translate('ChybaZacatkuGenerovani'));
                    if (debugMode) {
                        console.log('Chyba pri odesilani pozadavku na generovani terminalu: ' + textStatus);
                    }
                    umoznitZavreniDialogu();                   
                }
            }); 
        $('#terminal_generovani_info').text(info).css('color','black');
        
        $("#btnZavritDialog")
            .off("click")
            .hide();
    
        //zobrazeni dialogu a vypnuti escape, zaroven se spusti vypis tecek
        $("#terminal_generovani_dialog")        
            .dialog( {
                modal : true,
                resizable: false,
                width: "auto",
                height: "auto",
                closeOnEscape: false,
                open: function () {
                    loadingInt = setInterval(typeDots, 600);
                },
                close: function () {
                    clearInterval(loadingInt);
                }
        });
        
        return false;
    };
    
    /**
     * vypisuje 1..3 tecky
     * @returns 
     */
    var typeDots = function () {
        
        if(dots < 3) {
            $('#dots').append('.');
            dots++;
        } else {
            $('#dots').html('&nbsp;');
            dots = 0;
        }
    };
    
    /**
     * Ukonci vypis tecek a povoli uzavreni dialogu tlacitkem, nebo escapem
     * @returns 
     */
    var umoznitZavreniDialogu = function () {
        clearInterval(loadingInt);
        $('#dots').text('');
        $("#btnZavritDialog")
            .off("click")
            .on("click", function() {
                $("#terminal_generovani_dialog").dialog("close");  
                clearInterval(kontrolaStavuInt);
            })
            .show();
        $("#terminal_generovani_dialog").dialog( {
                closeOnEscape: true,
        });
    };
    
    /**
     * aktualizuje na strance vypsane informace o stavu terminalu (casy generovani, nastaveni, pocty nacteni, nastaveni)
     * @param {terminaly.stavTerminalu} stav objekt s informacemi o stavu terminalu
     * @returns 
     */
    var aktualizujStav = function (stav) {
        var tdPocetNacteni = $('#hlavickaterminalu_pocetnacteni td:last');
        var tdPocetNastaveni = $('#hlavickaterminalu_pocetnastaveni td:last');
        $(tdPocetNacteni).text(stav.pocetNacteni);
        $(tdPocetNastaveni).text(stav.pocetNastaveni);
        
        if (stav.pocetNacteni > 0) {
            $(tdPocetNacteni).removeClass('terminal_neuspesnanacteni');
            $(tdPocetNacteni).addClass('terminal_neuspesnanacteni'); 
        }
        else {
            $(tdPocetNacteni).removeClass('terminal_neuspesnanacteni'); 
        }

        if (stav.pocetNastaveni > 0) {
            $(tdPocetNastaveni).removeClass('terminal_neuspesnenastaveni');
            $(tdPocetNastaveni).addClass('terminal_neuspesnenastaveni'); 
        }
        else {
            $(tdPocetNastaveni).removeClass('terminal_neuspesnenastaveni'); 
        }

        $('#hlavickaterminalu_casnacteni td:last').text(stav.posledniNacteniStr); 
        $('#hlavickaterminalu_casnastaveni td:last').text(stav.posledniNastaveniStr);
    };
    
    /**
     * Zasila AJAXem GET pozadavek na zjisteni aktualniho stavu terminalu z databaze.
     * Ten pak porovna s aktualnim stavem a pokud doslo ke zmene vypise informaci do dialogu, umozni jeho zavreni 
     * a aktualizuje informace o stavu terminalu na strance.
     * 
     * @param string url
     * @param {terminaly.stavTerminalu} aktualniStav objekt s informacemi o stavu terminalu
     * @returns 
     */
    var zkontrolujStav = function (url, aktualniStav) {
        
        $.ajax({
            url: url+'&kontrolastavu',
            method: 'GET',
            /**
             * 
             * @param {terminaly.stavTerminalu} data json s aktualnim stavem terminalu
             * @returns {undefined}
             */
            success: function (data) {
                //server vratil informace o stavu, provede se porovnani dat
                if (data.result === 'OK') {
                    if (debugMode) {
                        console.log('Nacteny stav: ');
                        console.log(data);
                        console.log('Aktualni stav: ');
                        console.log(aktualniStav);
                    }
                    //doslo ke zmene stavu, vypisou se tyto zmeny a odblokuje dialog
                    if ((data.posledniNastaveni > aktualniStav.posledniNastaveni) || (data.pocetNastaveni > aktualniStav.pocetNastaveni)) {
                        aktualizujStav(data);
                        umoznitZavreniDialogu();
                        
                        //pri generovani doslo k chybe
                        if (data.pocetNastaveni > aktualniStav.pocetNastaveni) {
                            $('#terminal_generovani_info').text(ron.translate('GenerovaniNeuspesne'));
                        }
                        //terminal byl uspesne vygenerovan
                        else {
                            $('#terminal_generovani_info').text(ron.translate('GenerovaniUspesne'));
                        }
                        $('#zmenaStavu').val(1);
                        clearInterval(kontrolaStavuInt);
                    }
                }
                //server nevratil informace o stavu
                else {
                    $('#terminal_generovani_info').text(ron.translate('GenerovaniNeuspesne'));
                    $('#zmenaStavu').val(1);
                    umoznitZavreniDialogu();
                }
            },
            //pri odesilani pozadavku na zjisteni stavu doslo k chybe
            error : function (jqXHR, textStatus) {
                $('#terminal_generovani_info').text(ron.translate('ChybaNacteniStavu')); 
                $('#zmenaStavu').val(1);
                umoznitZavreniDialogu();
                if (debugMode) {
                    console.log('Chyba zjistovani stavu: ' + textStatus);
                }
            }
        }); 
    };
    
    
    $(':submit[name="nastaveni"]').on('click', provedGenerovani);      
};

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/script/terminaly.js <==

$(function() {
    let StavTerminalu = function() {
        this.posledniNastaveni = 0;
        this.posledniNacteni = 0;
        this.posledniNastaveniStr = '';
        this.posledniNacteniStr = '';
        this.pocetNastaveni = 0;
        this.pocetNacteni = 0;
        this.vysledekAgenta = 0;
        this.result = 0;
        this.errors = [];
    };


    var url = '?menuid=terminaly&record=';
    
    var info = $('#terminal_generovani_info').text();
    var kontrolaStavuInt;
    var provedGenerovani = function () {
        let
            $this = $(this),
            maxKontrola = $this.data('max-interval') * 60 * 1000,       //new Number(100000);
            intervalKontroly = $this.data('delka-intervalu') * 1000;        //new Number(5000);

        if (debugMode) {
            console.log('Kontrolu provadet ' + maxKontrola + ' ms, interval kontroly: ' + intervalKontroly + ' ms');
        }
        let
            terminalKod = $(':hidden[name="terminal_kod"]').val(),
            urlTerminalu = url+terminalKod,

            posledniNastaveni = parseInt($('#hlavickaterminalu_casnastaveni').data('value')),
            pocetNastaveni = parseInt($('#hlavickaterminalu_pocetnastaveni').data('value')),
            aktualniStav = {
                posledniNastaveni: posledniNastaveni,
                pocetNastaveni: pocetNastaveni
            };
        
        $.ajax({
                url: url+terminalKod,
                method: 'POST',
                data: {
                    terminal_kod: terminalKod,
                    nastaveni: true,
                    json: true
                },
                success: function (data) {
                    if (data) {
                        let
                            $generovaniInfo = $('#terminal_generovani_info'),
                            $zmenaStavu = $('#zmenaStavu');
                        if (data.vysledekAgenta) {
                            $generovaniInfo.text(ron.translate('GenerovaniUspesne'));
                            $zmenaStavu.val(1);
                            aktualizujStav(data);
                            umoznitZavreniDialogu();
                        }
                        else {
                            if (data.pocetNastaveni > aktualniStav.pocetNastaveni) {
                                aktualizujStav(data);
                                if ((data.errors) && (parseInt($zmenaStavu.val()) === 0)) {
                                    ron.showError(data, $generovaniInfo);
                                    $generovaniInfo.css('color','red');
                                }
                                umoznitZavreniDialogu();
                            }
                            else {
                                kontrolaStavuInt = setInterval(zkontrolujStav,intervalKontroly,urlTerminalu,aktualniStav);
                                setTimeout(function(){ 
                                    clearInterval(kontrolaStavuInt);
                                    if (debugMode) {
                                        console.log('Je zmena informacni zpravy: ' + $zmenaStavu.val());
                                    }
                                    if ((data.errors) && (parseInt($zmenaStavu.val()) === 0)) {
                                        ron.showError(data,$generovaniInfo);
                                        $generovaniInfo.css('color','red');
                                        aktualizujStav(data);                                    
                                    }
                                    umoznitZavreniDialogu();
                                }, maxKontrola);
                            }
                        }
                        
                        if (debugMode) {
                            console.log('Vysledek generovani: ');
                            console.log(data);
                        }
                        
                    }
                },
                error: function (jqXHR, textStatus) {
                    $('#terminal_generovani_info').text(ron.translate('ChybaZacatkuGenerovani'));
                    if (debugMode) {
                        console.log('Chyba pri odesilani pozadavku na generovani terminalu: ' + textStatus);
                    }
                    umoznitZavreniDialogu();                   
                }
            }); 
        $('#terminal_generovani_info').text(info).css('color','black');
        
        $("#btnZavritDialog")
            .off("click")
            .hide();
        $("#terminal_generovani_dialog")        
            .dialog( {
                modal : true,
                resizable: false,
                width: "auto",
                height: "auto",
                closeOnEscape: false,
                open: function () {
                    $("#stav_generovani").removeClass("d-none");
                }
        });
        
        return false;
    };
    var umoznitZavreniDialogu = function () {
        $("#stav_generovani").addClass("d-none");

        $("#btnZavritDialog")
            .off("click")
            .on("click", function() {
                $("#terminal_generovani_dialog").dialog("close");  
                clearInterval(kontrolaStavuInt);
            })
            .show();
        $("#terminal_generovani_dialog").dialog( {
                closeOnEscape: true
        });
    };
    var aktualizujStav = function (stav) {
        $('#hlavickaterminalu_pocetnacteni')
            .text(stav.pocetNacteni)
            .toggleClass('terminal_neuspesnanacteni', stav.pocetNacteni > 0);

        $('#hlavickaterminalu_pocetnastaveni')
            .text(stav.pocetNastaveni)
            .toggleClass('terminal_neuspesnenastaveni', stav.pocetNastaveni > 0);

        $('#hlavickaterminalu_casnacteni')
            .text(stav.posledniNacteniStr);

        $('#hlavickaterminalu_casnastaveni')
            .text(stav.posledniNastaveniStr);
    };
    var zkontrolujStav = function (url, aktualniStav) {
        
        $.ajax({
            url: url+'&kontrolastavu',
            method: 'GET',
            success: function (data) {
                if (data.result === 'OK') {
                    if (debugMode) {
                        console.log('Nacteny stav: ');
                        console.log(data);
                        console.log('Aktualni stav: ');
                        console.log(aktualniStav);
                    }
                    if ((data.posledniNastaveni > aktualniStav.posledniNastaveni) || (data.pocetNastaveni > aktualniStav.pocetNastaveni)) {
                        aktualizujStav(data);
                        umoznitZavreniDialogu();
                        if (data.pocetNastaveni > aktualniStav.pocetNastaveni) {
                            $('#terminal_generovani_info').text(ron.translate('GenerovaniNeuspesne'));
                        }
                        else {
                            $('#terminal_generovani_info').text(ron.translate('GenerovaniUspesne'));
                        }
                        $('#zmenaStavu').val(1);
                        clearInterval(kontrolaStavuInt);
                    }
                }
                else {
                    $('#terminal_generovani_info').text(ron.translate('GenerovaniNeuspesne'));
                    $('#zmenaStavu').val(1);
                    umoznitZavreniDialogu();
                }
            },
            error : function (jqXHR, textStatus) {
                $('#terminal_generovani_info').text(ron.translate('ChybaNacteniStavu')); 
                $('#zmenaStavu').val(1);
                umoznitZavreniDialogu();
                if (debugMode) {
                    console.log('Chyba zjistovani stavu: ' + textStatus);
                }
            }
        }); 
    };
    
    
    $(':submit[name="nastaveni"]').on('click', provedGenerovani);      
});
